RouteManager class abstract

A static utility class for managing navigation in a Flutter application using a GlobalKey.

To use this manager, you must:

  1. Provide the navigatorKey to your MaterialApp or CupertinoApp.
  2. Optionally, set onGenerateRoute if you are using named routes in addition to the static methods provided here.

Constructors

RouteManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentContext BuildContext
Gets the current BuildContext from the navigator key.
no setter

Static Methods

Navigates to a new page and removes all previous routes from the stack.
Navigates to a new page and removes all routes from the stack until the first route is reached.
Navigates to a new page by pushing it onto the navigation stack.
pop([Object? result]) → void
Pops the current route off the navigation stack.