pop static method
Pops the current route off the navigation stack.
Optionally, you can provide a result to be returned to the previous route.
Implementation
static void pop([Object? result]) {
return navigatorKey.currentState!.pop(result);
}
Pops the current route off the navigation stack.
Optionally, you can provide a result to be returned to the previous route.
static void pop([Object? result]) {
return navigatorKey.currentState!.pop(result);
}