onGenerateRoute function

Route? onGenerateRoute(
  1. RouteSettings settings
)

A placeholder function for onGenerateRoute.

If you are using named routes, you would implement your routing logic here. For this simple static route manager, we return null.

Implementation

Route<dynamic>? onGenerateRoute(RouteSettings settings) => null;